@@ -1,5 +1,4 @@
 setClass("gImageRGtk",
-         representation(filename="character"),
          contains="gComponentRGtk",
          prototype=prototype(new("gComponentRGtk"))
          )
@@ -17,12 +16,12 @@ setMethod(".gimage",
             force(toolkit)
             
             ## size if for Stock: one of MENU, SMALL_TOOLBAR, LARGE_TOOLBAR, BUTTON, DND, DIALOG
-            image = gtkImageNew()
+            image <- gtkImageNew()
             if(dirname == "stock") {
               if(is.null(size)) {
-                size =  GtkIconSize["menu"]
+                size <-  GtkIconSize["menu"]
               } else {
-                size = switch(toupper(size),
+                size <- switch(toupper(size),
                   "MENU"= GtkIconSize["menu"],
                   "SMALL_TOOLBAR"= GtkIconSize["small-toolbar"],
                   "LARGE_TOOLBAR"= GtkIconSize["large-toolbar"],
@@ -32,40 +31,55 @@ setMethod(".gimage",
                   GtkIconSize["menu"]
                   )
               }
-              filename = getstockiconname(filename) # in icons.R
+              filename <- getstockiconname(filename) # in icons.R
               image$SetFromStock(filename,size=size)
             } else {
               if(nchar(dirname) >0 )
-                filename = Paste(dirname,"/",filename) # / works for windows and unix?
+                filename <- Paste(dirname,"/",filename) # / works for windows and unix?
               if(!missing(filename) && file.exists(filename))
                 image$SetFromFile(filename)
             }
             
             ## pack into an event box so that we can get signals
-            evb = gtkEventBoxNew()
+            evb <- gtkEventBoxNew()
             evb$Add(image)
-            
-            obj = new("gImageRGtk", block=evb, widget=image, toolkit=toolkit,
-              filename=filename)
 
+            obj <- as.gWidgetsRGtk2(image, block=evb)
+#            obj = new("gImageRGtk", block=evb, widget=image, toolkit=toolkit
+
+            tag(obj,"filename") <- filename
             tag(obj,"doStock") <- dirname=="stock"
             if(dirname == "stock") {
               tag(obj,"size") <- size
             }
             if(!is.null(handler)) {
-              id = addhandlerclicked(obj, handler=handler, action=action)
+              id <- addhandlerclicked(obj, handler=handler, action=action)
             }
 
             ## attach?
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
-                container = gwindow(visible=TRUE)
+                container <- gwindow(visible=TRUE)
               add(container, obj,...)
             }
             
             invisible(obj)
           })
-          
+
+
+as.gWidgetsRGtk2.GtkImage <- function(widget, ...) {
+
+  theArgs <- list(...)
+  if(!is.null(theArgs$block))
+    block <- theArgs$block
+  else
+    block <- widget
+
+  obj <- new("gImageRGtk", block=block, widget=widget,
+             toolkit=guiToolkit("RGtk2"))
+
+  return(obj)
+}
 ### methods
 ### need to fuss with evb vs. label
 setMethod(".adddroptarget",
@@ -81,7 +95,7 @@ setMethod(".svalue",
           signature(toolkit="guiWidgetsToolkitRGtk2",obj="gImageRGtk"),
           function(obj, toolkit, index=NULL, drop=NULL, ...) {
             ## return name?
-            return(obj@filename)
+            return(tag(obj,"filename"))
           })
 
 setReplaceMethod(".svalue",
@@ -90,12 +104,12 @@ setReplaceMethod(".svalue",
                    ## value is a full filename
                    if(value != "" & file.exists(value))  {
                      obj@widget$SetFromFile(value)
-                     obj@filename=value
+                     tag(obj,"filename") <- value
                    } else if(value != "" & tag(obj,"doStock")) {
-                     iconname = getstockiconname(value)
+                     iconname <- getstockiconname(value)
                      obj@widget$SetFromStock(iconname,size=tag(obj,"size"))
                    } else {
-                     cat("File",value,"does not exist nor is a stock name.\n")
+                     cat(sprintf("File %sdoes not exist nor is a stock name.\n",value))
                    }
                    return(obj)
                  })
